# pytest-blink1

![Build Status](https://secure.travis-ci.org/vmalloe/pytest-blink1.png?branch=master )

A pytest plugin to emit notifications via the [Blink(1) RGB LED](https://blink1.thingm.com/)


## Installation

You can install "pytest-blink1" via pip from PyPI:

```
$ pip install pytest-blink1
```

After this, make sure you're running the API server via the blink1control utility.


## License

Distributed under the terms of the MIT license, "pytest-blink1" is free and open source software
